// Dynamic library loading routines for more platforms (Win32,Linux,BeOS)
// Written by Pavel Kanzelsberger (C)2002-2003
// kanzels@boxnetwork.sk, http://www.pixel32.sk

// This code has been copied from multiplatform library developed mainly for Pixel32,
// it contains many commonly used routines for all supported platforms.
// This allows high portability of Pixel32 with one (same) source code for
// DOS, Windows, Linux, FreeBSD, Solaris, QNX and BeOS

unit dll;

interface

function Load_DLL (filename:pchar):longint;
function Free_DLL (var handle:longint):longbool;
function GetProcAddr (handle:longint;procname:pchar):longint;

implementation

{$IFDEF Win32}
uses windows;

function Load_DLL (filename:pchar):longint;
 begin
 load_dll:=windows.LoadLibrary (filename);
 end;
function Free_DLL (var handle:longint):longbool;
 begin
 free_dll:=windows.FreeLibrary (handle);
 handle:=0;
 end;
function GetProcAddr (handle:longint;procname:pchar):longint;
 begin
 getprocaddr:=longint(windows.GetProcAddress(handle,procname));
 end;
{$ENDIF}

{$IFDEF Linux}
function dlopen (name:pchar;mode:longint):pointer; cdecl; external 'dl';
function dlsym (lib:pointer;name:pchar):pointer; cdecl; external 'dl';
function dlclose (lib:pointer):longint; cdecl; external 'dl';

function Load_DLL (filename:pchar):longint;
 begin
 load_dll:=longint(dlopen(filename,1));
 end;
function Free_DLL (var handle:longint):longbool;
 begin
 if handle<>0 then
  begin
  dlclose (pointer(handle));
  handle:=0;
  end;
 end;
function GetProcAddr (handle:longint;procname:pchar):longint;
 begin
 getprocaddr:=longint(dlsym(pointer(handle),procname));
 end;
{$ENDIF}

{$IFDEF BeOS}
function load_add_on (rpath:pchar):dword; cdecl; external 'root';
function unload_add_on (handle:dword):longbool; cdecl; external 'root';
function get_image_symbol (handle:dword;name:pchar;sclass:dword;var where:pointer):longbool; cdecl; external 'root';
 
function Load_DLL (filename:pchar):longint;
 begin
 load_dll:=load_add_on (filename);		// library file must exist!
 end;
function Free_DLL (var handle:longint):longbool;
 begin
 unload_add_on (handle);
 free_dll:=true;
 handle:=0;
 end;
function GetProcAddr (handle:longint;procname:pchar):longint;
var addr:pointer;
const B_SYMBOL_TYPE_ANY=5;
 begin
 get_image_symbol (handle,procname,0,addr);
 getprocaddr:=longint(addr);
 end;
{$ENDIF}

end.
