// SMPEG Library bindings for FreePascal (Win32,Linux,BeOS,QNX)
// Written by Pavel Kanzelsberger (C)2002-2003
// kanzels@boxnetwork.sk, http://www.pixel32.sk

{$PACKRECORDS C}
{$DEFINE Dynamic}

unit mpeglib;

interface

uses dll,sdl_video;

const smpeg_major_version=0;
      smpeg_minor_version=4;
      smpeg_patchlevel=3;

      smpeg_perror=-1;
      smpeg_stopped=0;
      smpeg_playing=1;

     {$IFDEF Win32}
      libsmpeg='smpeg.dll';
     {$ENDIF}

     {$IFDEF Linux}
      libsmpeg='libsmpeg.so';
     {$ENDIF}

     {$IFDEF BeOS}
      libsmpeg='/boot/home/config/lib/libsmpeg.so';
     {$ENDIF}

type smpeg=pointer;
     smpeg_info=record has_audio:longint;
                       has_video:longint;
                       width,height,current_frame:longint;
                       current_fps:double;
                       audio_string:array [0..79] of char;
                       audio_current_frame:longint;
                       current_offset,total_size:dword;
                       current_time,total_time:double;
                       end;
    psmpeg_info=^smpeg_info;
    smpeg_version=record major,minor,patch:byte;
                         end;

    smpeg_displaycallback=function (dst:psdl_surface;x,y:longint;w,h:dword):pointer; cdecl;

    filter=record flags:dword;
                  data:pointer;
                  callback:pointer;
                  destroy:procedure (filter:pointer); cdecl;
                  end;
    pfilter=^filter;

var smpeg_present:longbool;
    smpeg_lib:longint;

   {$IFDEF Dynamic}
    smpeg_new:function (fl:pchar;info:psmpeg_info;sdl_audio:longint):smpeg; cdecl;
    smpeg_new_descr:function (fl:longint;info:psmpeg_info;sdl_audio:longint):smpeg; cdecl;
    smpeg_error:function (mpeg:smpeg):pchar; cdecl;
    smpeg_getinfo:procedure (mpeg:smpeg;info:psmpeg_info); cdecl;
    smpeg_enableaudio:procedure (mpeg:smpeg;enable:longint); cdecl;
    smpeg_enablevideo:procedure (mpeg:smpeg;enable:longint); cdecl;
    smpeg_delete:procedure (mpeg:smpeg); cdecl;
    smpeg_setvolume:procedure (mpeg:smpeg;volume:longint); cdecl;
    smpeg_setdisplay:procedure (mpeg:smpeg;dst:psdl_surface;surflock:pointer;callback:pointer); cdecl;
    smpeg_setdisplayregion:procedure (mpeg:smpeg;x,y,w,h:longint); cdecl;
    smpeg_loop:procedure (mpeg:smpeg;rep:longint); cdecl;
    smpeg_scalexy:procedure (mpeg:smpeg;x,y:longint); cdecl;
    smpeg_scale:procedure (mpeg:smpeg;scale:longint); cdecl;
    smpeg_move:procedure (mpeg:smpeg;x,y:longint); cdecl;
    smpeg_play:procedure (mpeg:smpeg); cdecl;
    smpeg_pause:procedure (mpeg:smpeg); cdecl;
    smpeg_stop:procedure (mpeg:smpeg); cdecl;
    smpeg_rewind:procedure (mpeg:smpeg); cdecl;
    smpeg_seek:procedure (mpeg:smpeg;bytes:longint); cdecl;
    smpeg_skip:procedure (mpeg:smpeg;seconds:single); cdecl;
    smpeg_renderframe:procedure (mpeg:smpeg;framenum:longint); cdecl;
    smpeg_renderfinal:procedure (mpeg:smpeg;dst:psdl_surface;x,y:longint); cdecl;
    smpeg_status:function (mpeg:smpeg):longint; cdecl;
    smpeg_filter:function (mpeg:smpeg;filter:pfilter):pfilter; cdecl;

    smpeg_filter_null:function():pfilter; cdecl;
    smpeg_filter_bilinear:function():pfilter; cdecl;
    smpeg_filter_deblocking:function():pfilter; cdecl;
   {$ENDIF}

{$IFDEF Static}
 {$ERROR Not implemented yet :)}
{$ENDIF}

function smpeg_init:longbool;

implementation

function assigncall (name:pchar;addr:pointer):longbool;
var sym:dword;
 begin
 assigncall:=false;
 sym:=GetProcAddr (smpeg_lib,name);
 if sym=0 then exit;
 dword(pointer(addr)^):=sym;
 assigncall:=true;
 end;
function smpeg_init:longbool;
 begin
 smpeg_init:=false;
 smpeg_lib:=Load_DLL (libsmpeg);
 if smpeg_lib=0 then exit;

 if assigncall ('SMPEG_new',@smpeg_new)=false then exit;
 if assigncall ('SMPEG_new_descr',@smpeg_new_descr)=false then exit;
 if assigncall ('SMPEG_error',@smpeg_error)=false then exit;
 if assigncall ('SMPEG_getinfo',@smpeg_getinfo)=false then exit;
 if assigncall ('SMPEG_enableaudio',@smpeg_enableaudio)=false then exit;
 if assigncall ('SMPEG_enablevideo',@smpeg_enablevideo)=false then exit;
 if assigncall ('SMPEG_delete',@smpeg_delete)=false then exit;
 if assigncall ('SMPEG_setvolume',@smpeg_setvolume)=false then exit;
 if assigncall ('SMPEG_setdisplay',@smpeg_setdisplay)=false then exit;
 if assigncall ('SMPEG_setdisplayregion',@smpeg_setdisplayregion)=false then exit;
 if assigncall ('SMPEG_loop',@smpeg_loop)=false then exit;
 if assigncall ('SMPEG_scaleXY',@smpeg_scalexy)=false then exit;
 if assigncall ('SMPEG_scale',@smpeg_scale)=false then exit;
 if assigncall ('SMPEG_move',@smpeg_move)=false then exit;
 if assigncall ('SMPEG_play',@smpeg_play)=false then exit;
 if assigncall ('SMPEG_pause',@smpeg_pause)=false then exit;
 if assigncall ('SMPEG_stop',@smpeg_stop)=false then exit;
 if assigncall ('SMPEG_rewind',@smpeg_rewind)=false then exit;
 if assigncall ('SMPEG_seek',@smpeg_seek)=false then exit;
 if assigncall ('SMPEG_renderFrame',@smpeg_renderframe)=false then exit;
 if assigncall ('SMPEG_renderFinal',@smpeg_renderfinal)=false then exit;
 if assigncall ('SMPEG_status',@smpeg_status)=false then exit;
 if assigncall ('SMPEG_filter',@smpeg_filter)=false then exit;
 if assigncall ('SMPEGfilter_null',@smpeg_filter_null)=false then exit;
 if assigncall ('SMPEGfilter_bilinear',@smpeg_filter_bilinear)=false then exit;
 if assigncall ('SMPEGfilter_deblocking',@smpeg_filter_deblocking)=false then exit;

 smpeg_init:=true;
 end;
function smpeg_done:longbool;
 begin
 Free_DLL (smpeg_lib);
 smpeg_present:=false;
 end;

end.
